# PermitDurationChallengeReviewRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**internal_user_identifier** | **str** | Max length 100 characters | [optional] 
**internal_user_name** | **str** | Max length 100 characters | [optional] 
**review_status** | [**DurationChallengeReviewStatus**](DurationChallengeReviewStatus.md) |  | 
**reason_for_non_acceptance** | **str** | Max length 500 characters Required if review_status &#x3D; duration_challenge_not_accepted | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

